@@ -45,6 +45,11 @@ class Task(APIResource):
         """
         return cls._list(search_term, page, page_size, sort, filter_, api_key)
 
+    @classmethod
+    def get_task_id(cls, task_name: str, api_key: str = None) -> WhatifyResponse:
+        task_id = cls.list(search_term=task_name)['hits'][-1]['id']
+        return task_id
+
     @classmethod
     def get(cls, id: int, api_key: str = None) -> WhatifyResponse:
         """
