@@ -402,12 +402,12 @@ class MyWhatify:
         return my_toolkit.Connector.get_s3_path(user_token=user_token)
 
     @classmethod
-    def read_to_pandas_df(cls, file_name: str, user_token: str = None):
-        return my_toolkit.Connector.read_to_pandas_df(file_name=file_name, user_token=user_token)
+    def read_to_pandas_df(cls, file_name: str, user_token: str = None, **kwargs):
+        return my_toolkit.Connector.read_to_pandas_df(file_name=file_name, user_token=user_token, **kwargs)
 
     @classmethod
-    def write_pandas_df_to_s3(cls, df, file_name: str, user_token: str = None):  # s3_client, bucket, path, df):
-        return my_toolkit.Connector.write_pandas_df_to_s3(df=df, user_token=user_token)
+    def write_pandas_df_to_s3(cls, df, file_name: str, user_token: str = None, **kwargs):  # s3_client, bucket, path, df):
+        return my_toolkit.Connector.write_pandas_df_to_s3(df=df, file_name=file_name, user_token=user_token, **kwargs)
 
     #############################
     ###       data_file       ###
